==> histogrammar-1.0.33.tar.gz: histogrammar-1.0.33/histogrammar/dfinterface/__init__.py <==
# Copyright (c) 2021 ING Wholesale Banking Advanced Analytics
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
# the Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
# FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
# COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
# IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

from .addmethods import add_pandas_methods, add_sparksql_methods

try:
    from pyspark.sql import DataFrame as sdf
    # add function to create histogrammar histograms
    add_sparksql_methods(cls=sdf, prefix='hg_')
except (ModuleNotFoundError, AttributeError):
    pass

try:
    from pandas import DataFrame as pdf
    # add function to create histogrammar histograms
    add_pandas_methods(cls=pdf, prefix='hg_')
except (ModuleNotFoundError, AttributeError):
    pass

==> histogrammar-1.1.0.tar.gz: histogrammar-1.1.0/histogrammar/dfinterface/__init__.py <==
# Copyright (c) 2021 ING Wholesale Banking Advanced Analytics
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
# the Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
# FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
# COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
# IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

from .addmethods import add_pandas_methods, add_sparksql_methods

try:
    from pyspark.sql import DataFrame as sdf

    # add function to create histogrammar histograms
    add_sparksql_methods(cls=sdf, prefix="hg_")
except (ModuleNotFoundError, AttributeError):
    pass

try:
    from pandas import DataFrame as pdf

    # add function to create histogrammar histograms
    add_pandas_methods(cls=pdf, prefix="hg_")
except (ModuleNotFoundError, AttributeError):
    pass
